@@ -1,22 +1,11 @@
 import time
 import datetime as dt
-from zoneinfo import ZoneInfo
 from urllib3.exceptions import ReadTimeoutError
 
 import pandas as pd
 from influxdb_client import InfluxDBClient
 
-from tide.utils import check_and_return_dt_index_df
-
-
-def _date_objects_tostring(date: dt.datetime | pd.Timestamp, tz_info=None):
-    if date.tzinfo is None:
-        if tz_info is None:
-            raise ValueError("tz_info must be provided for naive datetime objects.")
-        date = date.replace(tzinfo=ZoneInfo(tz_info))
-
-    date_utc = date.astimezone(ZoneInfo("UTC"))
-    return date_utc.strftime("%Y-%m-%dT%H:%M:%SZ")
+from tide.utils import check_and_return_dt_index_df, date_objects_tostring
 
 
 def _single_influx_request(
@@ -29,13 +18,14 @@ def _single_influx_request(
     org: str,
     token: str,
     tz_info: str = "UTC",
+    timeout: int = 10000,
 ) -> pd.DataFrame:
-    client = InfluxDBClient(url=url, org=org, token=token)
+    client = InfluxDBClient(url=url, org=org, token=token, timeout=timeout)
     query_api = client.query_api()
     query = f"""
         from(bucket: "{bucket}")
-        |> range(start: {_date_objects_tostring(start, tz_info)}, 
-                 stop: {_date_objects_tostring(stop, tz_info)})
+        |> range(start: {date_objects_tostring(start, tz_info)}, 
+                 stop: {date_objects_tostring(stop, tz_info)})
         |> filter(fn: (r) => r["_measurement"] == "{measurement}")
         |> map(fn: (r) => ({{r with tide: r.{tide_tags[0]}
     """
@@ -75,6 +65,7 @@ def get_influx_data(
     token: str,
     split_td: str | dt.timedelta | pd.Timedelta = None,
     tz_info: str = "UTC",
+    request_timeout: int = 10000,
     max_retry: int = 5,
     waited_seconds_at_retry: int = 5,
     verbose: bool = False,
@@ -132,6 +123,9 @@ def get_influx_data(
         Timezone for interpreting start and stop times.
         Must be a valid timezone name from the IANA Time Zone Database.
 
+    request_timeout : int, default 10 000
+        Number of ms to wait before the request timeout
+
     max_retry : int, default 5
         Maximum number of retry attempts for failed queries.
         Only applies to ReadTimeoutError exceptions.
@@ -159,7 +153,7 @@ def get_influx_data(
 
     Examples
     --------
-    >>> from tide import get_influx_data
+    >>> from tide.influx import get_influx_data
     >>> import pandas as pd
     >>> # Fetch last 24 hours of data
     >>> df = get_influx_data(
@@ -225,6 +219,7 @@ def get_influx_data(
                         org=org,
                         token=token,
                         tz_info=tz_info,
+                        timeout=request_timeout,
                     )
                 )
                 break
